.jetpack-video-wrapper {
	margin-bottom: 1.6em;
}

.jetpack-video-wrapper > embed,
.jetpack-video-wrapper > iframe,
.jetpack-video-wrapper > object,
.jetpack-video-wrapper > .wp-video {
	margin-bottom: 0;
}
